@@ -33,10 +33,6 @@ class BookEndpoints(PublicResourceEndpointSet):
     resource_class = Book
     group_name = 'Book'
 
-    @staticmethod
-    async def authorize(principal, book_id: int = None, *args, **kwargs):
-        return True
-
     class singleton_subresource(PublicResourceEndpointSet):
         resource_name = 'singleton'
         singleton = True
@@ -94,6 +90,9 @@ class BookEndpoints(PublicResourceEndpointSet):
     async def destroy(self, book_id: int):
         return book_id
 
+    async def exists(self, book_id: int) -> bool:
+        return book_id == 1
+
     async def index(self) -> Book.List:
         return self.render_to_response(
             [
